@@ -1,6 +1,8 @@
 import _ from 'lodash';
 import chrome from 'ui/chrome';
 
+const baseUrl = chrome.addBasePath('/api/kibana/suggestions/values');
+
 export function filterParamsPhraseController($http, $scope, config) {
   const shouldSuggestValues = this.shouldSuggestValues = config.get('filterEditor:suggestValues');
 
@@ -25,7 +27,7 @@ export function filterParamsPhraseController($http, $scope, config) {
       field: field.name
     };
 
-    return $http.post(chrome.addBasePath(`/api/kibana/suggestions/values/${field.indexPattern.id}`), params)
+    return $http.post(`${baseUrl}/${field.indexPattern.title}`, params)
       .then(response => response.data)
       .catch(() => []);
   }
